# AUTO GENERATED FILE - DO NOT EDIT

export ''_buttontest

"""
    ''_buttontest(;kwargs...)

A ButtonTest component.
Component description
Keyword arguments:
- `id` (String; optional): Unique ID to identify this component in Dash callbacks.
"""
function ''_buttontest(; kwargs...)
        available_props = Symbol[:id]
        wild_props = Symbol[]
        return Component("''_buttontest", "ButtonTest", "pollination_dash_io", available_props, wild_props; kwargs...)
end

